import { csv } from 'd3';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';

const sectionColors = [
  		'green', 'brown', 'Pink', 
		  ]; //Different colors for representation
//dataset Url made raw from github
const csvUrl = 'https://gist.githubusercontent.com/Bhanuteja-1807/9e7f866e0b4446e10eebe06191eda2ac/raw/2bb92cb24fe95cb641afff16003fb68aa20cfa73/Iris.csv';
//fetching data from dataset
const fetchData = async () => {
  const data = await csv(csvUrl);
  return data;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const xAxisTickFormat = number =>
  	format('.4~g')(number);

const render = (data, total) => {
  const pieData = pie().value(d=>d.Species)(data);
  const colors = scaleOrdinal()
  	.domain(data)
  	.range(sectionColors);
  
  const arcGenerator = d3.arc()
  .innerRadius(0)
  .outerRadius(250);

  //arc
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(175)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  
  sections.enter()
    .append("path")
    .attr("d", segments)
  	.attr("fill", d => colors(d.data.Species));
  //section label
  sections
    .enter()
    .append('text')
    .text(d => xAxisTickFormat((d.data.Species/1000))+"K")
    .attr("transform", function(d) { return "translate(" + arcGenerator.centroid(d) + ")";  })
    .style("text-anchor", "middle")
  	.style('fill', 'black')
    .style("font-size", 15);
  //legends
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.Species));
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.Company);
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat((d.data.Carsales/1000))+"K");
}

const run = async () => {
  let data = await fetchData()
  let total = 0
  data.forEach(d=>{
    d.Carsales = +d.Carsales;
    total += d.Carsales
  });
	render(data,total);
};
run();